"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const minimist_1 = __importDefault(require("minimist"));
const update_notifier_1 = __importDefault(require("update-notifier"));
const create_project_1 = require("../create-project");
const render_project_1 = require("../render-project");
const select_syntax_js_1 = require("./select-syntax.js");
const init_1 = require("./init");
const install_status_1 = require("./install-status");
const util_1 = require("../util");
const argv = minimist_1.default(process.argv.slice(2));
const projectPath = path_1.default.resolve('.');
const help = `
  Usage: estilo [command]

  Commands:

    init                initialize an estilo project in current folder
    render              render all the colorschemes and themes
    add-syntax          open dialog: add more syntax templates
    add-airline         open dialog: add a new Airline style
    add-lightline       open dialog: add a new Lightline style
    version             output version number
    help                show this help
`;
update_notifier_1.default({
    pkg: util_1.pkg,
    updateCheckInterval: 1000 * 60 * 60 * 24 // 1 day
}).notify();
const [command, destination] = argv._;
const noQuestions = argv.y;
const actions = {
    help: () => console.log(help),
    version: () => console.log(util_1.pkg.version),
    init: () => init_1.init(path_1.default.resolve(destination || '.'), noQuestions),
    render: () => render_project_1.renderProject(create_project_1.createProject(projectPath)),
    'add-syntax': () => select_syntax_js_1.selectSyntax(projectPath),
    'add-airline': () => install_status_1.installStatus(projectPath, 'airline'),
    'add-lightline': () => install_status_1.installStatus(projectPath, 'lightline')
};
if (!command)
    actions.help();
else {
    const action = actions[command];
    if (action)
        action();
    else {
        console.log('Command not found');
        console.log(help);
    }
}
