"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.init = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const inquirer_1 = __importDefault(require("inquirer"));
const mkdirp_1 = __importDefault(require("mkdirp"));
const cp_file_1 = __importDefault(require("cp-file"));
const chalk_1 = __importDefault(require("chalk"));
const install_templates_1 = require("./install-templates");
const blankTermOrigin = path_1.default.resolve(__dirname, '../../templates/terminal.yml');
const defaultPalette = 'myblue: \'#99ccff\'';
function init(projectPath, noQuestions) {
    const folderName = path_1.default.basename(projectPath);
    if (noQuestions) {
        return createBoilerplate(projectPath, {
            name: folderName,
            author: '',
            version: '1.0.0',
            url: '',
            license: 'MIT',
            airline: true,
            lightline: true,
            description: ''
        });
    }
    const questions = [
        {
            type: 'input',
            name: 'name',
            message: 'Project name:',
            default: folderName
        },
        {
            type: 'input',
            name: 'version',
            message: 'Version:',
            default: '1.0.0'
        },
        {
            type: 'input',
            name: 'license',
            message: 'License:',
            default: 'MIT'
        },
        {
            type: 'input',
            name: 'author',
            message: 'Author:'
        },
        {
            type: 'input',
            name: 'url',
            message: 'Project url:'
        },
        {
            type: 'input',
            name: 'description',
            message: 'Short description:'
        }
    ];
    inquirer_1.default.prompt(questions).then(function (answers) {
        createBoilerplate(projectPath, answers);
    });
}
exports.init = init;
function createBoilerplate(projectPath, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const addonsFolder = path_1.default.resolve(projectPath, 'estilo/addons');
        const termPath = path_1.default.resolve(addonsFolder, 'terminal.yml');
        const estiloStr = `name: '${options.name}'
version: '${options.version || ''}'
license: '${options.license || ''}'
author: '${options.author || ''}'
url: '${options.url || ''}'
description: '${options.description || ''}'
colorschemes:
  - name: ${options.name}
    background: 'dark'
    palette: ${options.name}`;
        fs_1.default.writeFileSync(path_1.default.resolve(projectPath, 'estilo.yml'), estiloStr);
        mkdirp_1.default.sync(path_1.default.resolve(projectPath, 'estilo'));
        mkdirp_1.default.sync(path_1.default.resolve(projectPath, 'estilo', 'syntax'));
        mkdirp_1.default.sync(path_1.default.resolve(projectPath, 'estilo', 'palettes'));
        mkdirp_1.default.sync(addonsFolder);
        fs_1.default.writeFileSync(path_1.default.resolve(projectPath, 'estilo/palettes', options.name + '.yml'), defaultPalette);
        yield cp_file_1.default(blankTermOrigin, termPath);
        install_templates_1.installTemplates(['base.yml']);
        console.log(chalk_1.default.green.bold('✓  Your project is ready\n'));
    });
}
