"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.installStatus = void 0;
const path_1 = __importDefault(require("path"));
const inquirer_1 = __importDefault(require("inquirer"));
const fs_1 = __importDefault(require("fs"));
const cp_file_1 = __importDefault(require("cp-file"));
const mkdirp_1 = __importDefault(require("mkdirp"));
const chalk_1 = __importDefault(require("chalk"));
const originPaths = {
    airline: 'templates/status/airline.yml',
    lightline: 'templates/status/lightline.yml'
};
function installStatus(projectPath, brand) {
    const statusFolderPath = path_1.default.resolve(projectPath, 'estilo', brand);
    mkdirp_1.default.sync(statusFolderPath);
    const installedStyles = fs_1.default.readdirSync(statusFolderPath)
        .map(n => n.slice(0, -4));
    const questions = [
        {
            type: 'input',
            message: 'Enter style name:',
            name: 'stylename',
            validate: (input) => {
                const stylename = input.trim();
                if (!stylename)
                    return 'That\'s not a name';
                if (installedStyles.includes(stylename)) {
                    return 'That style already exists';
                }
                else {
                    return true;
                }
            }
        }
    ];
    inquirer_1.default.prompt(questions).then(function (answers) {
        return __awaiter(this, void 0, void 0, function* () {
            const templatePath = path_1.default.resolve(__dirname, '../..', originPaths[brand]);
            const filepath = path_1.default.resolve(statusFolderPath, answers.stylename + '.yml');
            yield cp_file_1.default(templatePath, filepath);
            const stylename = answers.stylename.trim();
            console.log(chalk_1.default.green(`New ${brand} style: ${stylename}`));
            console.log(`==> ${filepath}`);
        });
    });
}
exports.installStatus = installStatus;
