"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createProject = void 0;
const path_1 = __importDefault(require("path"));
const util_1 = require("./util");
const loaders_1 = require("./loaders");
function createProject(folderPath) {
    return {
        folderPath,
        estiloVersion: util_1.estiloVersion,
        config: util_1.loadYml(folderPath, 'estilo.yml').content,
        palettes: loadPalettes(folderPath),
        syntax: util_1.ymlsInFolder(folderPath, 'estilo/syntax').flatMap(loaders_1.loadSyntax),
        terminalSyntax: loaders_1.loadTerminal(folderPath),
        airlineStyles: loadAllStatus(folderPath, 'airline'),
        lightlineStyles: loadAllStatus(folderPath, 'lightline'),
        mustaches: loaders_1.loadMustaches()
    };
}
exports.createProject = createProject;
function loadPalettes(folderPath) {
    const filepaths = util_1.ymlsInFolder(folderPath, 'estilo/palettes');
    const palettes = {};
    filepaths.forEach(file => {
        const palette = loaders_1.loadPalette(file);
        palettes[palette.name] = palette;
    });
    return palettes;
}
function loadAllStatus(folderPath, brand) {
    const brandpath = path_1.default.resolve(folderPath, 'estilo');
    const filepaths = util_1.ymlsInFolder(brandpath, brand);
    const statusStyle = {};
    filepaths.forEach(filepath => {
        const style = loaders_1.loadStatus(filepath, brand);
        statusStyle[style.name] = style;
    });
    return statusStyle;
}
