"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadStatus = exports.loadMustaches = exports.loadTerminal = exports.loadSyntax = exports.loadPalette = void 0;
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const hexterm_1 = __importDefault(require("hexterm"));
const util_1 = require("./util");
const crash_1 = require("./crash");
const chalk_1 = __importDefault(require("chalk"));
function loadPalette(filepath) {
    const { content } = util_1.loadYml(filepath);
    const palette = {
        filepath,
        name: path_1.default.basename(filepath, '.yml'),
        colors: {}
    };
    Object.keys(content).forEach(name => {
        const hexcolor = content[name].trim();
        if (!util_1.isHexColor(hexcolor))
            crash_1.crash('Wrong color', { filepath, name });
        palette.colors[name] = {
            hex: hexcolor.startsWith('#') ? hexcolor : '#' + hexcolor,
            xterm: hexterm_1.default(hexcolor).toString()
        };
    });
    return palette;
}
exports.loadPalette = loadPalette;
function loadSyntax(filepath) {
    const { content } = util_1.loadYml(filepath);
    return Object.keys(content)
        .map(name => ({
        filepath,
        name,
        rule: content[name].trim()
    }))
        .filter(rule => rule.rule);
}
exports.loadSyntax = loadSyntax;
function getTerminalTemplatePath(folderPath) {
    const addonsPath = path_1.default.resolve(folderPath, 'estilo/addons');
    const legacyPath = path_1.default.resolve(addonsPath, 'nvim-term.yml');
    const newPath = path_1.default.resolve(addonsPath, 'terminal.yml');
    if (fs_1.default.existsSync(legacyPath) && !fs_1.default.existsSync(newPath)) {
        console.log(chalk_1.default.yellow.bold('⚠  Warning: Legacy terminal config path'));
        console.log(chalk_1.default.yellow(`Please rename ${legacyPath} to ${newPath}\n`));
        return legacyPath;
    }
    else {
        return path_1.default.resolve(addonsPath, 'terminal.yml');
    }
}
function loadTerminal(folderPath) {
    const filepath = getTerminalTemplatePath(folderPath);
    const { content } = util_1.loadYml(filepath);
    const terminalSyntax = {};
    Object.keys(content).forEach(prop => {
        const colorname = content[prop].trim();
        if (!colorname)
            return;
        terminalSyntax[prop] = colorname;
    });
    return terminalSyntax;
}
exports.loadTerminal = loadTerminal;
function loadMustaches() {
    const folder = path_1.default.resolve(__dirname, '../mustaches');
    const filenames = ['colorscheme', 'airline', 'lightline'];
    const mustaches = {};
    filenames.forEach(filename => {
        const filepath = path_1.default.resolve(folder, filename + '.hbs');
        const txt = fs_1.default.readFileSync(filepath, 'utf8');
        mustaches[filename] = txt;
    });
    return mustaches;
}
exports.loadMustaches = loadMustaches;
function loadStatus(filepath, brand) {
    const { content } = util_1.loadYml(filepath);
    const statusStyle = {
        name: path_1.default.basename(filepath, '.yml'),
        filepath: filepath,
        syntax: {}
    };
    Object.keys(content).forEach(name => {
        const txt = content[name].trim();
        statusStyle.syntax[name] = txt.split(/\s+/);
    });
    statusParts[brand].forEach(part => {
        const block = statusStyle.syntax[part];
        if (!block)
            crash_1.crash('Missing block in status', { filepath, block: part });
        if (!block[0]) {
            crash_1.crash('Missing foreground in status block', { filepath, block: part });
        }
        if (!block[1]) {
            crash_1.crash('Missing background in status block', { filepath, block: part });
        }
    });
    return statusStyle;
}
exports.loadStatus = loadStatus;
const statusParts = {
    airline: [
        'normal1',
        'normal2',
        'normal3',
        'insert1',
        'insert2',
        'insert3',
        'replace1',
        'replace2',
        'replace3',
        'visual1',
        'visual2',
        'visual3',
        'inactive1',
        'inactive2',
        'inactive3'
    ],
    lightline: [
        'normal1',
        'normal2',
        'normal3',
        'normal4',
        'normal5',
        'normalError',
        'normalWarning',
        'inactive1',
        'inactive2',
        'inactive3',
        'inactive4',
        'inactive5',
        'insert1',
        'insert2',
        'insert3',
        'insert4',
        'insert5',
        'replace1',
        'replace2',
        'replace3',
        'replace4',
        'replace5',
        'visual1',
        'visual2',
        'visual3',
        'visual4',
        'visual5',
        'tablineLeft',
        'tablineSelected',
        'tablineMiddle',
        'tablineRight'
    ]
}; // , ctrlp
