"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.renderStatus = void 0;
const handlebars_1 = __importDefault(require("handlebars"));
const crash_1 = require("./crash");
const util_1 = require("./util");
function parseStatusColors(syntax, palette) {
    const out = {};
    Object.keys(syntax).forEach(partName => {
        const [fgName, bgName] = syntax[partName];
        const fg = palette.colors[fgName];
        const bg = palette.colors[bgName];
        if (!fg)
            crash_1.crash('Missing foreground color', { palette: palette.filepath, color: fgName });
        if (!bg)
            crash_1.crash('Missing background color', { palette: palette.filepath, color: bgName });
        out[partName] = { fg, bg };
    });
    return out;
}
function renderStatus(config, project, brand) {
    const palette = project.palettes[config.palette];
    if (!palette) {
        crash_1.crash('Palette does not exist', { palette: config.palette, brand, style: config.style });
    }
    const brandStyles = {
        airline: project.airlineStyles,
        lightline: project.lightlineStyles
    };
    const syntaxFile = brandStyles[brand][config.style];
    if (!syntaxFile)
        crash_1.crash('Cannot find status style file', { name: config.name });
    const syntax = syntaxFile.syntax;
    const c = parseStatusColors(syntax, palette);
    const render = handlebars_1.default.compile(project.mustaches[brand]);
    const info = {
        name: config.name,
        description: config.description,
        url: project.config.url,
        author: project.config.author,
        license: project.config.license,
        estiloVersion: util_1.estiloVersion
    };
    const context = Object.assign(c, { info });
    return render(context);
}
exports.renderStatus = renderStatus;
